#!/usr/bin/env python

#-----------------------------------------------------------------------
# database.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sqlite3
import contextlib

#-----------------------------------------------------------------------

_DATABASE_URL = 'file:penny.sqlite'

#-----------------------------------------------------------------------

def get_books():

    books = []

    with sqlite3.connect(_DATABASE_URL + '?mode=ro',
        isolation_level=None, uri=True) as connection:

        with contextlib.closing(connection.cursor()) as cursor:

            query_str = "SELECT isbn, author, title FROM books"
            cursor.execute(query_str)

            table = cursor.fetchall()
            for row in table:
                book = {'isbn': row[0], 'author': row[1],
                    'title': row[2]}
                books.append(book)

    return books

#-----------------------------------------------------------------------

def add_book(isbn, author, title):

    with sqlite3.connect(_DATABASE_URL + '?mode=rw',
        uri=True) as connection:

        with contextlib.closing(connection.cursor()) as cursor:

            query_str = "INSERT INTO books (isbn, author, title) "
            query_str += "VALUES (?, ?, ?)"
            try:
                cursor.execute(query_str, [isbn, author, title])
                return True
            except sqlite3.IntegrityError:
                return False

#-----------------------------------------------------------------------

def delete_book(isbn):

    with sqlite3.connect(_DATABASE_URL + '?mode=rw',
        uri=True) as connection:

        with contextlib.closing(connection.cursor()) as cursor:

            query_str = "DELETE FROM books WHERE isbn = ?"
            cursor.execute(query_str, [isbn])

#-----------------------------------------------------------------------

# For testing:

def write_books(books):
    for book in books:
        print('%s | %s | %s' %
            (book['isbn'], book['author'], book['title']))

def _test():
    print('----------------------------------')
    print('Testing get_books()')
    print('----------------------------------')
    print()
    books = get_books()
    write_books(books)
    print()

    print('----------------------------------')
    print('Testing add_book()')
    print('----------------------------------')
    print()
    successful = add_book('456', 'Kernighan', 'New Book')
    if successful:
        print('Add was successful')
        print()
        books = get_books()
        write_books(books)
        print()
    else:
        print('Add was unsuccessful')
        print()
        write_books(books)
        print()
    successful = add_book('456', 'Kernighan', 'New Book')
    if successful:
        print('Add was successful')
        print()
        books = get_books()
        write_books(books)
        print()
    else:
        print('Add was unsuccessful')
        print()
        write_books(books)
        print()

    print('----------------------------------')
    print('Testing delete_book()')
    print('----------------------------------')
    print()
    delete_book('456')
    books = get_books()
    write_books(books)
    print()
    delete_book('456')
    books = get_books()
    write_books(books)

if __name__ == '__main__':
    _test()
